#!/usr/bin/perl -w

use strict;
use IO::File;

my %machine = (
	altair		=> 'MITS Altair 8080',
	altairz80	=> 'MITS Altair 8080 (Z80)',
	eclipse		=> 'Data General Eclipse',
	gri		=> 'GRI Corportaion GRI-909 and GRI-99',
	h316		=> 'Honeywell H316',
	hp2100		=> 'Hewlett-Packard 2100',
	i1401		=> 'IBM 1401',
	i1620		=> 'IBM 1620',
	i7094		=> 'IBM 7090/7094',
	ibm1130		=> 'IBM 1130',
	id16		=> 'Interdata 16b',
	id32		=> 'Interdata 32b',
	lgp		=> 'Royal-Mcbee LGP-30/LGP-21',
	nova		=> 'Data General Nova',
	pdp1		=> 'Digital Equipment Corporation PDP-1',
	pdp4		=> 'Digital Equipment Corporation PDP-4',
	pdp7		=> 'Digital Equipment Corporation PDP-7',
	pdp8		=> 'Digital Equipment Corporation PDP-8',
	pdp9		=> 'Digital Equipment Corporation PDP-9',
	pdp10		=> 'Digital Equipment Corporation PDP-10',
	pdp11		=> 'Digital Equipment Corporation PDP-11',
	pdp15		=> 'Digital Equipment Corporation PDP-15',
	s3		=> 'IBM System 3',
	sds		=> 'Scientific Data Systems SDS 940',
	vax		=> 'Digital Equipment Corporation VAX',
	vax780		=> 'Digital Equipment Corporation VAX-780'
);

my %title = (
	altair		=> 'Altair',
	altairz80	=> 'Altair Z80',
	eclipse		=> 'Eclipse',
	gri		=> 'GRI',
	h316		=> 'H316',
	hp2100		=> 'HP 2100',
	i1401		=> 'IBM 1401',
	i1620		=> 'IBM 1620',
	i7094		=> 'IBM 7090/7094',
	ibm1130		=> 'IBM 1130',
	id16		=> 'Interdata 16b',
	id32		=> 'Interdata 32b',
	lgp		=> 'LGP-30/LGP-21',
	nova		=> 'Nova',
	pdp1		=> 'PDP-1',
	pdp4		=> 'PDP-4',
	pdp7		=> 'PDP-7',
	pdp8		=> 'PDP-8',
	pdp9		=> 'PDP-9',
	pdp10		=> 'PDP-10',
	pdp11		=> 'PDP-11',
	pdp15		=> 'PDP-15',
	s3		=> 'IBM System 3',
	sds		=> 'SDS 940',
	vax		=> 'VAX',
	vax780		=> 'VAX-780'
);

foreach my $exec( `ls bin` ) {
	chomp $exec;
	if( exists $machine{ $exec } ) {
		my $fh = new IO::File "> $exec.pxml";
		defined $fh or die "Can't open $exec.pxml for writing: $!\n";
		print $fh "<?xml version=\"1.0\" encoding=\"ISO-8859-1\" standalone=\"yes\"?>\n";
		print $fh "<appinfo>\n";
		print $fh "\t<title>$title{$exec}</title>\n";
		print $fh "\t<standalone>yes</standalone>\n";
		if( -f "share/$exec.png" ) {
			print $fh "\t<icon>share/$exec.png</icon>\n";
		}
		elsif( $exec eq 'altairz80' ) {
			print $fh "\t<icon>share/altair.png</icon>\n";
		}
		else {
			print $fh "\t<icon>share/simh.png</icon>\n";
		}
		print $fh "\t<description>\n";
		print $fh "\t\tSIMH simulator for the $machine{$exec}\n";
		print $fh "\t\tfrom The Computer History Simulation Project.\n";
		print $fh "\t</description>\n";
		print $fh "\t<author>\n";
		print $fh "\t\t<website>http://simh.trailing-edge.com/</website>\n";
		print $fh "\t\t<name>Bob Supnik</name>\n";
		print $fh "\t</author>\n";
		print $fh "\t<version>3.8</version>\n";
		print $fh "\t<exec>bin/$exec</exec>\n";
		print $fh "\t<category>Emulators<category>\n";
		print $fh "</appinfo>\n";
		$fh->close;
	}
	else {
		warn "Unknown machine '$exec'\n";
	}
}

